---
title: "White Paper: Kotahi Current State"
subtitle: "An overview of the current state of Kotahi. Last updated Sept 2021."
date: "2021-09-15"
author: Adam Hyde
category: "study-paper"
---
<p>The Kotahi workflow is very configurable and can support very linear, to very concurrent,
workflows. In addition, the submission types supported are configurable. These two features together mean that
Kotahi can support a wide variety of use cases and workflow models.</p>
<p class="paragraph">This document outlines Kotahi as it is configured for a typical Journal workflow. Please note
that this is just one configured pathway and many parts of what you will see in this document are configurable to
meet your needs.</p>
<p class="paragraph"><em>Please note&#x2014;Kotahi is undergoing heavy continuous development. For an insight into
the current issues please see </em><a href="https://gitlab.coko.foundation/kotahi/kotahi/-/issues?state=opened"
rel target="blank"><em>here</em></a><. Some pre-recorded demos are provided, please click on the demo icon to
review. In addition, all images can be clicked on for a more detailed view. This White Paper is a light
overview, for in depth detail please contact Coko (email included below) for a full demo and discussion.</em>
</p>
<h3>Typical Journal Workflow</h3>
<p class="paragraph">For the purposes of this document we will look at the following configuration which is being
used by the Aperture Neuro journal (Organization of Human Brain Mapping).</p>
<p class="paragraph"></p>
<figure><img src="/images/uploads/sspKotahi-01.png">
<figcaption class="decoration">Aperture Workflow in Kotahi</figcaption>
</figure>
<p class="paragraph">The Aperture workflow in sequential notation looks something like this:</p>
<ol>
<li>
<p class="paragraph">Author creates new submission (a link, attachment, or ingested docx)</p>
</li>
<li>
<p class="paragraph">Author completes submission data</p>
</li>
<li>
<p class="paragraph">Author submits</p>
</li>
<li>
<p class="paragraph">Managing Editor views manuscript</p>
</li>
<li>
<p class="paragraph">Managing Editor desk reject (can reject submission)</p>
</li>
<li>
<p class="paragraph">Managing Editor assigns to Senior Editor</p>
</li>
<li>
<p class="paragraph">Senior Editor checks manuscript</p>
</li>
<li>
<p class="paragraph">Senior Editor assigns to Handing Editor</p>
</li>
<li>
<p class="paragraph">Handling Editor assigns Reviewers</p>
</li>
<li>
<p class="paragraph">Reviewers accept / decline invitation</p>
</li>
<li>
<p class="paragraph">Reviewers review</p>
</li>
<li>
<p class="paragraph">Reviewers submit review</p>
</li>
<li>
<p class="paragraph">Handling Editor makes decision (accept/revise-&gt;goto 9)</p>
</li>
<li>
<p class="paragraph">Handling Editor publishes (production covered later in this document)</p>
</li>
</ol>
<p class="paragraph">We can break the above into 4 high level stages:</p>
<ol>
<li>
<p class="paragraph">Author submission (steps 1,2,3)</p>
</li>
<li>
<p class="paragraph">Editor Assignment (steps 4,5,6,7,8)</p>
</li>
<li>
<p class="paragraph">Reviewer Assignment and Review (steps 10,11,12)</p>
</li>
<li>
<p class="paragraph">Editor Decision (steps 13,14)</p>
</li>
</ol>
<p class="paragraph">The following sections will look at each stage and the associated user Interfaces.</p>
<h3>Author Submission</h3>
<h4>Login</h4>
<p class="paragraph">All users authenticate before they can use Kotahi. Aperture supports the ORCID OAuth protocol
and process. However this can be replaced by any shared login system or with a sign-up and sign-in process. Upon
login all users are directed to their Dashboard where they can view all the manuscripts they are working on (as
authors, reviewers, or editors).</p>
      <p class="paragraph"><a href="/images/uploads/orcid.gif" target="_new"><img src="/images/uploads/Demo-icon2-150x150.png"/></a></p>
<h4>Submission Types</h4>
<p class="paragraph">Kotahi supports any type of filetype as a submission attachment as well as link submissions
(for submitting code stored in repositories or Jupyter notebook instances etc).</p>
<p class="paragraph">In addition, if a submission is in MS Word docx format then Kotahi will ingest and convert the
file into an internal stored and editable data format for editing in Kotahi&#x2019;s internal <a
href="https://waxjs.net/" rel target="blank">Scholarly Word Processor</a>. In this later mode, Kotahi becomes a
complete Single Source Publishing system (more on this later).</p>
      <p class="paragraph"><a href="https://gitlab.coko.foundation/kotahi/kotahi/-/wikis/uploads/ea04b6b9c83dac26d97ed3d31770dfcd/Screencast_01-12-2021_06_51_12_PM.webm" target="_new">View Video.></a></p>
<h4>Submission Form</h4>
<p class="paragraph">Submission data can be captured by user entry with the Submission Form. The creation and
ongoing maintenance of the Submission Form is done by the Journal Admin with the internal Form Creation user
interface (see later in this document).</p>
      <p class="paragraph"><a href="https://gitlab.coko.foundation/kotahi/kotahi/-/wikis/uploads/d17257d127926b5d92705f7fc3f7847b/Screencast_01-12-2021_06_55_19_PM.webm" target="_new">View Video.</a></p>
<p class="paragraph">Please see below for the Aperture form captured in its entirety (click to see the entire form).
</p>
<p class="paragraph"></p>
<figure><img
src="/images/uploads/sspKotahi-02.png">
<figcaption class="decoration">Example Submission Form</figcaption>
</figure>
<h4>Submission</h4>
<p class="paragraph">Upon completion of the submission form, the manuscript and its associated declarations and data
can be submitted. The author will be asked to agree to any terms and conditions (configurable) before the material
can be submitted. Upon submission, the state for the manuscript changes from &#x2018;unsubmitted&#x2019; to
&#x2018;submitted&#x2019;&#x2014;this information (current state) is displayed on the Dashboard as well as in many
other places throughout Kotahi.</p>
<h3>Editor Assignment</h3>
<p class="paragraph">Editors break down to the following generic roles:</p>
<ul>
<li>
<p class="paragraph">Managing Editor</p>
</li>
<li>
<p class="paragraph">Senior Editor</p>
</li>
<li>
<p class="paragraph">Handling Editor</p>
</li>
<li>
<p class="paragraph">Editor (misc)</p>
</li>
</ul>
<p class="paragraph">Editors can view manuscripts they are associated with via the Dashboard as well as seeing all
manuscripts on the Manuscripts Page (permissions permitting).</p>
<h4>Manuscripts Page</h4>
<p class="paragraph">The Managing Editor can view new submissions via the Manuscripts Page (click to enlarge).</p>
<p class="paragraph"></p>
<figure><img
src="/images/uploads/sspKotahi-03.png">
<figcaption class="decoration">Kotahi Manuscripts Page (with example data)</figcaption>
</figure>
<p class="paragraph">Columns can be sorted by Creation Dates, State etc.</p>
<p class="paragraph">Managing Editors (ME) can choose a new (or any) manuscript to view by clicking on
&#x2018;View&#x2019;. Alternatively, the ME can click on &#x2018;Control Panel&#x2019; to view the manuscript,
submission data, and the submission&#x2019;s associated workflow controls.</p>
<h4>Control Panel</h4>
<p class="paragraph">The Control Panel displays the Manuscript, Submission Data and workflow controls for the
selected manuscript as per below (click to enlarge).</p>
<p class="paragraph"></p>
<figure><img
src="/images/uploads/sspKotahi-04.png">
<figcaption class="decoration">Kotahi Control Panel</figcaption>
</figure>
<p class="paragraph">Please note, the above screenshot is soon to be replaced with three separate tabs for 1)
workflow controls 2) manuscript 3) submission data (as per <a
href="https://gitlab.coko.foundation/kotahi/kotahi/-/issues/621" rel target="blank">this issue</a>).</p>
<p class="paragraph">From the Control Panel, the ME can reject the manuscript or assign a Senior Editor. Upon
assigning a Senior Editor, the manuscript will appear on the Dashboard for that editor. The Senior Editor can then
access the Control Panel for that manuscript, view the manuscript and data, and assign a Handling Editor.</p>
<h3>Reviewer Assignment and Review</h3>
<p class="paragraph">The Handling Editor (HE) can access the Control Panel for the manuscript from their Dashboard.
They can then review the manuscript and submission data. The next step is for the HE to invite reviewers. The
Invite Reviewers page is accessible via the Control Panel.</p>
<p class="paragraph"></p>
<figure><img
src="/images/uploads/sspKotahi-05.png">
<figcaption class="decoration">Kotahi Reviewer Management</figcaption>
</figure>
<p class="paragraph">At this stage of invitation, the editor can also decide if the reviewer is doing their own
review or a shared review.</p>
<p class="paragraph"></p>
<figure><img
src="/images/uploads/sspKotahi-06.png">
<figcaption class="decoration">Reviewer Management showing shared review option</figcaption>
</figure>
<p class="paragraph"><em>Screenshot taken from CB (t.b.a) Instance</em></p>
<p class="paragraph">Reviewers receive an email with the invitation to review the manuscript. Contained in the email
is additional information about the manuscript (this is set via the Form Builder, see below).</p>
<p class="paragraph">The reviewer can then accept or reject the invitation via their Dashboard (soon also via the
email). The Reviewer can then access the manuscript, filtered submission data, and the review form via the
Dashboard. </p>
      <p class="paragraph"><a href="https://gitlab.coko.foundation/kotahi/kotahi/-/wikis/uploads/a83e723e0fbd4f2219cf5b1fc4b96685/Screencast_01-12-2021_07_08_00_PM.webm" target="_new">View video.</a></p>
<p>The Review Page has a section for writing the review and attaching files:</p>
<p class="paragraph"></p>
<figure><img
src="/images/uploads/sspKotahi-07.png">
<figcaption class="decoration">Kotahi Reviewer Form</figcaption>
</figure>
<h3>Editor Decision</h3>
<p class="paragraph">When reviews are complete, the HE can access the reviews via the Control Panel for the
manuscript and decide on whether to accept, reject, or request a revision. Secondary revision types are managed
through email templates (see below).</p>
      <p class="paragraph"><a href="/images/uploads/reviews.gif" target="_new"><img src="/images/uploads/Demo-icon2-150x150.png"/></a></p>
<p class="paragraph">The HE can write their response to the author in the panel provided. The text is shown to the
author on the submission form (connected to versions, see below).</p>
<p class="paragraph">The author can then revise both the submission data and the manuscript and resubmit. The
process continues until the article is ready to publish. Editors can assign the same reviewers, or new reviewers
per round.</p>
<h3>Communication</h3>
<p class="paragraph">Kotahi leverages many realtime tools for communication as well as utlizing its own email
template system. Realtime communication is supported by &#x2018;presence indicators&#x2019; to indicate if a user
is logged in at that time. Also supported is live video communication for the editorial staff (linked from the
Manuscripts Page). Live chat is also available per submission for communication between authors and editorial
staff, as well as private chats for the editorial staff to discuss the submission.</p>
<p class="paragraph"></p>
<figure><img
src="/images/uploads/sspKotahi-08.png">
<figcaption class="decoration">Kotahi Chat (Author view)</figcaption>
</figure>
<p class="paragraph"><em>Author&#x2014;Editor chat embedded in the author submission pane (click to enlarge).</em>
</p>
<p class="paragraph"></p>
<figure><img
src="/images/uploads/sspKotahi-09.png">
<figcaption class="decoration">Kotahi Chat (Editorial view)</figcaption>
</figure>
<p class="paragraph"><em>Editorial chat for staff only (per manuscript).</em></p>
<p class="paragraph">Emails can be sent for each manuscript via the email template controls. The Publisher can
configure as many templates as they like. Emails can be sent to existing users or people with no account. A record
of all emails sent is kept as a retrievable log within the editorial staff chat.</p>
<p class="paragraph"></p>
<figure><img
src="/images/uploads/sspKotahi-10.png">
<figcaption class="decoration">Email Management</figcaption>
</figure>
<p class="paragraph"><em>Screenshot taken from the CB instance of Kotahi.</em></p>
<h3>Versions</h3>
<p class="paragraph">Submissions are managed per revision round. Each round creates a new version of both the
submission data and the manuscript attachments/internal content store. Revision history can be browsed by authors
and editorial staff alike. Earlier versions cannot (of course) be edited.</p>
      <p class="paragraph"><a href="/images/uploads/versions.gif" target="_new"><img src="/images/uploads/Demo-icon2-150x150.png"/></a></p>
<h3>Single Source Publishing</h3>
<p class="paragraph">If docx files are submitted, Kotahi can be a complete end-to-end <a
href="https://coko.foundation/single-source-publishing/" rel target="blank">Single Source Publishing</a> System.
Docx content is ingested and converted to Kotahi&#x2019;s internal data format. The content is then editable via
the Wax web-based word processor built into Kotahi.</p>
<h3>JATS</h3>
<p class="paragraph">The JATS production interface is currently being built. The JATS production interface will also
support automated PDF output via <a href="https://pagedjs.org/" rel target="blank">pagedjs</a>, and SEO optimised
HTML for pushing to publish interfaces.</p>
<p class="paragraph"></p>
<figure><img
src="/images/uploads/sspKotahi-11.png">
<figcaption class="decoration">JATS Export</figcaption>
</figure>
<h3>Publishing</h3>
<p class="paragraph">Aperture is going live with the FLAX publish front end. Flax is a new product from Coko which
is connects directly to Kotahi for realtime publishing of articles while being a completely extensible CMS for
building entire Journal sites. Kotahi has an extensible ingestion API and publishing API. These APIs allow for a
vast variety of (for example) publishing integrations. NCRC, for example publish to a Google spreadsheet (since
they are processing existing preprint URLs) as well as registering reviews with DOIs on Crossref. If the target
system for publishing offers an integration endpoint of any kind, then Kotahi can integrate with it.</p>
<h3>The Form Builder</h3>
<p class="paragraph">The Form Builder sounds humble but it is an immensely powerful tool. The Form Builder enables
the admin/ME to build the submission forms using a web interface. However, the interface also allows for the
tagging of each field with unique IDs (useful for building JATS/XML at export time), identifying which fields will
be shown to reviewers when inviting them to review, controlling taxonomy, identifying which columns are displayed
on the Manuscripts Page, and it can even be used to extend the Control Panel UI. The Form Builder will
increasingly become an central part of the Kotahi platform. Form Builders are much underestimated.</p>
      <p class="paragraph"><a href="/images/uploads/form.gif" target="_new"><img src="/images/uploads/Demo-icon2-150x150.png"/></a></p>
<h3>Reports</h3>
<p class="paragraph">Reports are integrated into Kotahi and are pretty comprehensive. We have opted for dynamic
rendering to improve the user enjoyment of the Kotahi UI.</p>
      <p class="paragraph"><a href="/images/uploads/Kotahi-summary-report4-1.gif" target="_new"><img src="/images/uploads/Demo-icon2-150x150.png"/></a></p>
<h3>&#xA0;Workflow Configuration</h3>
<p class="paragraph">There are immense workflow configuration options. So far, almost all are via config files but
we have a UI config manager design. While we will use the above workflow, the following are two workflow examples
for the Novel Coronavirus Research Consortium and CBinstances:</p>
<p class="paragraph"></p>
<figure><img
src="/images/uploads/sspKotahi-12.png">
<figcaption class="decoration"><em>NCRC Kotahi Workflow</em></figcaption>
</figure>
<p class="paragraph"></p>
<p class="paragraph"></p>
<figure><img
src="/images/uploads/sspKotahi-13.png">
<figcaption class="decoration">CB Kotahi Workflow</figcaption>
</figure>
<p class="paragraph"></p>
<h3>Summary</h3>
<p class="paragraph">Kotahi is a modern scholarly publishing platform. It is built with modern technologies with
modern, efficient workflows in mind. The platform is also very modular, extensible, and configurable. There is
almost no element of the system that is immutable&#x2014;all elements can be changed if required. In addition
Kotahi leverages modern realtime communication protocols and together with the Single Source Publishing design the
entire system offers publishers enormous futureproofing and workflow optimization opportunities.</p>
<p class="paragraph">Lastly, <em>all</em> aspects of Kotahi are open source and liberally licensed (MIT). Coko
exists to support organizations wanting to hire us to extend Kotahi or go it alone. In all development scenarios,
Coko facilitates the multiple organizations extending Kotahi to ensure the community is building upon each
other&#x2019;s work&#x2014;this helps ensure lowering the burden of development cost and time as well as
eliminating possible duplication of efforts.</p>
<p class="paragraph">For more information contact Adam Hyde&#x2014;<a href="http://adam@coko.foundation" rel
target="blank">adam@coko.foundation</a></p>
