---
title: "Single Source Publishing"
subtitle: "A investigation of what Single Source Publishing is and how this 'holy grail' can be achieved."
author: Adam Hyde
date: "2021-08-16"
category: "article"
---

<p>note: this is a combination of 6 articles published in a series in 2021.</p>
  <h2>The Problem</h2>
   <p class="paragraph">Publishing has long suffered from broken workflows that slow down the time to publish and
      unnecessarily inflate the cost to publish. Publishing of all kinds suffers from these inefficiencies. Some of the
      problems are general, others are very idiosyncratic and particular to perhaps just one publisher.</p>
    <p class="paragraph">However, no matter what kind of publishing you do, there is a good chance you suffer from a
      disconnect between content creation processes and production processes.</p>
    <p class="paragraph">In many publishing environments authors, copy editors, proofers etc create and improve content
      primarily in one tool (usually Microsoft Word). The content creation process feeds into the production process
      where production staff create a multitude of other formats &#x2013; HTML, PDF (for print and screen), possibly XML
      and ebook formats etc.</p>
    <p class="paragraph">To convert to these file formats, the content has to either be programmatically converted to
      various target formats via software (eg Pandoc or bespoke software), or manually converted by people using
      software (eg InDesign). If manually executed Publishers either sling the content &#x2018;over the wall&#x2019; to a
      publishing services vendor or contractor, or they employ internal staff. The folks doing these conversions belong
      to the general category of &#x2018;production people&#x2019; &#x2013; usually programmers, designers, or
      &#x2018;format wranglers&#x2019;.</p>
    <p class="paragraph">Here is the problem. Workflows that look similar to the above, which is most publishing
      workflows, separate the content creation from the content production. This disconnect separates &#x2018;the
      who&#x2019; (who does the work), &#x2018;the how&#x2019; (what tools are used), and importantly &#x2018;the
      what&#x2019; &#x2013; what files are worked on. The people, the tools, and the working files all change as the
      content jumps from content creation to content production.</p>
    <figure><img
        src="/images/uploads/A1-Img1-and-A4-img4.jpg">
    </figure>
    <p class="paragraph">To understand why this is a problem, we just have to consider this one very simple scenario:
      what if there need to be changes to the content after it has entered the production stage?</p>
    <p class="paragraph">Generally, if content needs to be changed while in the &#x2018;production stage&#x2019; it
      requires several steps</p>
    <ol>
      <li>
        <p class="paragraph">the content people, using their own tools, communicate the changes required</p>
      </li>
      <li>
        <p class="paragraph">the production people, using their own tools, make the changes for each output format</p>
      </li>
      <li>
        <p class="paragraph">the content staff check the changes.</p>
      </li>
    </ol>
    <p class="paragraph">All this also requires managing because there is a lot of necessary back and forth which in
      turn creates a lot of expensive overhead for making even the simplest of changes. Additionally, jumping the gap
      from creation to production introduces errors.</p>
    <p class="paragraph">Take a simple book example &#x2013; if an error is discovered by the author (which is common)
      after the content has gone to the designer, then the author must write the comments somewhere (email/MS
      Word/annotated PDF), and send them to the designer. The designer must then interpret the results, which can in
      itself cause errors as designers are seldom content domain experts, and apply the corrections in (for example)
      InDesign. The designer then sends a PDF to the author to check..and so on&#x2026;</p>
    <p class="paragraph">Or a simple Journal example &#x2013; the production staff have discovered from proofs that
      figures are in the wrong place. This information must be communicated to (for example) the publishing services
      provider (via email, MS Word, annotated PDF etc). The vendor interprets the information, makes the changes in
      their (various) tools, and sends back to the publisher to check&#x2026; and so on&#x2026;</p>
    <p class="paragraph">In each of the above examples, larger publishers also have staff to manage the communication of
      changes, track the changes, check the changes etc. It is quite an ordeal that costs time and money. If publishers
      don&#x2019;t do this well, the consequence is that more errors are introduced.</p>
    <p class="paragraph">This is the problem &#x2018;single sourcing&#x2019; is meant to solve. Single sourcing is a
      general approach to publishing workflows that is intended to avoid disconnecting the content creation and
      production processes &#x2013; saving time and money, and reducing errors.</p>
    <h3> What is Single Source Publishing?</h3>
    <p class="paragraph">What exactly is single sourcing and how does it avoid disconnecting content creation and
      production?</p>
    <p class="paragraph">Single sourcing isn&#x2019;t a specific solution, it is a general idea that must be
      intentionally designed into a publisher&#x2019;s workflow. Single sourcing changes how people work and often
      requires a different tooling. The secret really, if we zoom out to a high-level abstraction of the problem, is to
      work out how the content creation and production folks can work in a shared &#x2018;environment&#x2019; where they
      all work on the same files, the same source files &#x2013; hence the term &#x2018;single source&#x2019;.</p>
    <p class="paragraph"></p>
    <figure><img
        src="/images/uploads/A1-Img2.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">In a single source environment if a change needs to be made while the content is in production
      the content people can make the change themselves. Less time and communication required, less to-and-fro, less
      management overhead, and fewer errors.</p>
    <p class="paragraph">There are many ways of achieving single sourcing. Any book publisher could solve this by, for
      example, asking their authors to write their books in InDesign, saving the files to a shared server somewhere.
      Authors, copy editors, and designers (etc) could all collaborate in the same tool, changing the same files, and
      all changes could smoothly flow into the final output at the push of a button. Success!</p>
    <p class="paragraph">There is a good reason why you haven&#x2019;t heard of anyone doing this despite the fact that
      this is a&#xA0;<em>technically</em>&#xA0;elegant single source solution. No author is going to head off into the
      woods and spend 6 months in a cabin to conjure up their masterpiece &#x2013; in InDesign. Not ever. InDesign is a
      production tool, it is not designed for authors.</p>
    <p class="paragraph">The above example may seem frivolous, but it gets down to the core of the problem. Single
      sourcing, to be effective, must be done with tools that not only share the same source for content creation and
      production but also respect the different tool-cultures of content creators and production people.</p>
    <p class="paragraph">Amazingly, this last point is often not taken into consideration. Unfortunately, too often, the
      content creators are never asked about the kinds of tools they like to work with. Their tool-culture is ignored.
      This is actually a problem with how tooling is designed and built, and worthy of one or more articles in itself.
    <h2>A Solution</h2>
    <p class="paragraph">Let&#x2019;s look at a simple tool used for single source publishing on the web &#x2013;
      WordPress &#x2013; which will help us understand some of the more complex problems Publishers face.</p>
    <p class="paragraph">WordPress is a single source publishing system. To produce a post, the author does the
      following:</p>
    <ol>
      <li>
        <p class="paragraph">writes the post within WordPress, using the basic web editor supplied</p>
      </li>
      <li>
        <p class="paragraph">presses &#x2018;Update&#x2019; and the content is pushed through to the web</p>
      </li>
    </ol>
    <p class="paragraph">That is it. The important thing to understand here is that content is authored in one place,
      and at publish time, that content is transformed into the target output &#x2013; in this case a blog post shared
      on the web.</p>
    <figure><img
        src="/images/uploads/A2-Img1.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">Let&#x2019;s add a little complexity as it is hard to really understand the value of single
      source publishing from such a simple example. We will add more people and more outputs.</p>
    <h3>Single Source and Multiple Actors</h3>
    <p class="paragraph">Before publishing, other actors &#x2013; copy editors, illustrators etc &#x2013; might also
      work on the content. These folks will also work within WordPress to edit the same post. All these people can
      collaborate on the same source for the post. When it is time to publish, the process is still as simple as
      pressing publish. There are no other versions of the content that need to be merged, checked, managed etc. Single
      source has, even in this basic example, saved us a lot of hassle.</p>
    <p class="paragraph">Furthermore, all the stakeholders here are using familiar tools. The WordPress editor is a
      pretty easy editor to use if you are creating content for the web.</p>
    <h3>Single Source and Multiple Outputs</h3>
    <p class="paragraph">Now let&#x2019;s look at adding multiple outputs. What if we wish to display the same WordPress
      blog post to look good on both mobile and desktop devices. In this case, CSS (the set of rules used by designers
      that describe how webpages should look) has the ability to identify whether the content is being displayed on a
      small or large screen. CSS changes how the content is displayed accordingly.</p>
    <p class="paragraph">As if by magic, we have effectively solved the problem of displaying the same content for two
      different types of outputs &#x2013; desktop and mobile displays.</p>
    <figure><img
        src="/images/uploads/A2-Img2.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <h3>So what&#x2019;s the problem?</h3>
    <p class="paragraph">If you were building WordPress for the first time, and you needed to cater for the above
      outputs (HTML + CSS for 2 display sizes), what file format would you choose to store your source?</p>
    <p class="paragraph">No prizes for choosing HTML. To transform from HTML to HTML &amp; HTML is cheap because there
      is (in simple terms) no transformation needed. This is exactly what the smart folks at WordPress have done.</p>
    <figure><img
        src="/images/uploads/A2-Img3.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">The content you are editing in WP is stored as HTML. Exactly that same source is directly
      transferred to the web at publish time.</p>
    <p class="paragraph">The trouble starts when you require significantly different types of outputs. What if, for
      example, you required not just HTML but also EPUB, Screen PDF, PDF for Print, XML etc. In cases where you require
      multiple output types, which is most publishing scenarios, you must choose a source file format that can undergo
      significant transformation into all of the output formats you require.</p>
    <figure><img
        src="/images/uploads/A2-Img4.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">So, how do you choose the right source file format for your publishing system?</p>
    <p class="paragraph">When designing a publishing system you face two basic questions, in this order:</p>
    <ol>
      <li>
        <p class="paragraph">what output formats do I need?</p>
      </li>
      <li>
        <p class="paragraph">what source file would best lend itself to transformation into the outputs?</p>
      </li>
    </ol>
    <p class="paragraph">After these two questions there are a lot of secondary questions (requirements) that will come
      to bear on the problem, but let&#x2019;s keep it simple for now.</p>
    <p class="paragraph">Unfortunately, the process for designing systems too often takes the following format, in this
      order:</p>
    <ol>
      <li>
        <p class="paragraph">what source file format is currently in fashion? (hint: it has been XML for the last 20+
          years)</p>
      </li>
      <li>
        <p class="paragraph">how do I build a system around that format?</p>
      </li>
    </ol>
    <p class="paragraph">Unfortunately, this latter thought process has driven the publishing industry into building
      expensive and inefficient systems and largely prevented the industry from moving towards more elegant workflows.
    </p>
    <h2>Is Automation the Answer?</h2>
       <p class="paragraph">Let's look a little closer at the automation of file format conversion. Obviously it would be awesome if we could push a button in our imaginary publishing system and
      all the outputs would roll out automagically &#x2013; fully formed, perfect and beautiful.</p>
    <p class="paragraph"></p>
    <figure><img
        src="/images/uploads/A3-Img1.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">Is such automation possible? Let&#x2019;s have a closer look at the types of conversion
      involved:</p>
      <ol>
      <li>Structural Conversion</li>
      <li>Typesetting</li>
      </ol>
    <h3>Structural Conversion</h3>
    <p class="paragraph">There are two types (roughly) of structural conversion &#x2013; upconversion, and
      downconversion.</p>
    <h3><strong>Downconversion</strong></h3>
    <p class="paragraph">To create a simpler structure (eg plain text) from any source format, the transformation mostly
      means removing information (structure).</p>
    <p class="paragraph"></p>
    <figure><img
        src="/images/uploads/A3-Img2.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">Removing structure is easy (usually), we just throw stuff away.</p>
    <h3><strong>Upconversion</strong></h3>
    <p class="paragraph">To get from our source file to a more complex structure, we need to add information
      (structure).</p>
    <p class="paragraph"></p>
    <figure><img
        src="/images/uploads/A3-Img3.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">Adding structure is doable but not as easy.</p>
    <p class="paragraph">A simple diagram to help us understand up and down conversion would be as follows:</p>
    <p class="paragraph"></p>
    <figure><img
        src="/images/uploads/A3-Img4.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">Down-conversion is generally an easier target for automation. Up-conversion is more likely to
      require human intervention.</p>
    <h3>Typesetting</h3>
    <p class="paragraph">Another category of conversion is typesetting. Typesetting means we require a change in the
      look and feel of the output (design).</p>
    <p class="paragraph">There are two approaches to typesetting &#x2013; &#x2018;automatic typesetting&#x2019; (which
      is done by a machine) and manual typesetting (done by a human).</p>
    <h3><strong>Automatic Typesetting</strong></h3>
    <p class="paragraph">Automatic typesetting is when a designer sets up a bunch of rules (templates) and then
      &#x2018;a machine&#x2019; applies those rules to the content.</p>
    <p class="paragraph">Automatic typesetting is possible to achieve in some Publishing contexts but the more complex
      your design requirements, the harder it is to achieve.</p>
    <h3><strong>Manual Typesetting</strong></h3>
    <p class="paragraph">When a designer uses a design tool such as InDesign to produce the required design, this is
      manual typesetting.</p>
    <p class="paragraph">Again, the more sophisticated the design, the more likely it is to require human intervention
      to produce the desired result.</p>
    <h3>Where does that leave us?</h3>
    <p class="paragraph">If we can achieve all of our conversions &#x2013; structural conversions and typesetting
      &#x2013; automatically, then we are in a winning situation. We can start with a source file and then press a
      button and all of our outputs will be generated automagically. This is single source publishing achieved through
      automation.</p>
    <p class="paragraph">Automatic conversion is most likely to be achievable where we have either:</p>
    <ol>
      <li>
        <p class="paragraph">very simple conversions</p>
      </li>
      <li>
        <p class="paragraph">moderate expectations from our conversions.</p>
      </li>
    </ol>
    <p class="paragraph">While often true in &#x2018;web publishing&#x2019;, these two conditions are seldom true for
      publishers. Publishers, generally speaking, have high expectations for all their conversions and their outputs are
      often complex.</p>
    <p class="paragraph">What does this mean? In most publishing contexts, this level of automation is not achievable
      &#x2013; we will require manual processing, and manual processing inevitably leads to the broken workflows we were
      trying to avoid. If, for example, we want to introduce a manual design tool such as InDesign, then we are changing
      the people, tools, and source as discussed above and we are deciding against a single source workflow.</p>
    <p class="paragraph">If we are to achieve single source publishing, but we can&#x2019;t do it by automation alone,
      then we need another strategy.</p>
    <p class="paragraph">To achieve all the efficiencies of the single source workflow that we have discussed before, we
      need to work out how humans (content producers, designers, production people) and machines can utilize different
      tools, respecting their tool-cultures, while working on the <i>same source</i> to create all the desired outputs. How is
      this possible?</p>
    <h2>For the Good of The System</h2>
      <blockquote>
      <p class="source-note">&#x201C;[XML].. is seen as something that must be endured by content authors for the
        greater good of the enterprise.&#x201D;<br><a
          href="https://web.archive.org/web/20060826041249/http://www.elkera.com/cms/articles/seminars_and_presentations/planning_a_single_source_publishing_application_for_business_documents/"
          rel target="blank">Peter Meyer, 2005</a></p>
    </blockquote>
    <p class="paragraph">It seems (from above) that our dream of perfect automated output is dead, so how do we
      ensure all the folks involved in preparing content to publish &#x2013; authors, editors, copy editors, designers,
      format wranglers etc &#x2013; can work on the same source?</p>
    <p class="paragraph">Let&#x2019;s look, at a somewhat simplified level, at the operations each of the main
      categories of stakeholders have to perform.</p>
    <p class="paragraph">Content &#x2013; ability to change the content</p>
    <p class="paragraph">Design &#x2013; ability to change the look and feel of outputs</p>
    <p class="paragraph">Format &#x2013; ability to change the structure of outputs</p>
    <p class="paragraph">The challenge for systems designers is to consider tooling that can help each group of
      stakeholders work efficiently while they share the same canonical source.</p>
    <p class="paragraph">&#xA0;</p>
    <figure><img
        src="/images/uploads/A4-Img1.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">&#xA0;</p>
    <p class="paragraph">To solve this problem, the publishing sector&#x2019;s &#x2018;system thinking&#x2019; has
      largely been, to date, driven by what experts believe is the best file format. This &#x2018;file-format-first
      thinking&#x2019; has looked like this:</p>
    <p class="paragraph"></p>
    <figure><img
        src="/images/uploads/A4-Img2.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">This thinking has lead us to where we are today, and today we have broken, disjointed
      workflows.</p>
    <p class="paragraph">To bring about the efficiencies we are after, we need to think in this direction:</p>
    <p class="paragraph"></p>
    <figure><img
        src="/images/uploads/A4-Img3.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">What if the file format was the last decision you made when constructing ecosystems of
      publishing tools, rather than the first thing you decided?</p>
    <p class="paragraph">Are we more interested in making decisions based on how we can help people work more
      efficiently, or making decisions based on source file formats? When designing systems the publishing sector has,
      for the past 25 years, appeared to have answered &#x201C;source file formats&#x201D; to this question. This is
      largely why the sector has been driven away from single source publishing systems and is mired in the kind of
      broken, slow, expensive processes we discussed in earlier and we illustrated as follows:</p>
    <figure><img
        src="/images/uploads/A1-Img1-and-A4-img4.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">When we started our discussion of single source publishing systems in this article, we talked a
      lot about source file formats. However, it appears that deciding on the actual source file format to be used is
      (literally) the last question we must ask. The questions we need to ask are as follows, in this order:</p>
    <ol>
      <li>
        <p class="paragraph">what tools can people efficiently use?</p>
      </li>
      <li>
        <p class="paragraph">what group of these tools share the same file format?</p>
      </li>
      <li>
        <p class="paragraph">what is the file format?</p>
      </li>
    </ol>
    <p class="paragraph">We need to start looking at&#xA0;<em>ecosystems of tools</em>&#xA0;that people can use
      efficiently to work together on the same source, and then adopt that source format, whatever it may be&#x2026;..
      this might be a lengthy exercise as there are a lot of tools and formats out there, so I&#x2019;ll make it easy on
      you.</p>
   <h2>Workflow-First Systems</h2>
   <p class="paragraph">In the above section, we concluded that it is a very good idea to build systems around ecologies of tools that share the same source file format, rather than deciding
      on the source file format before workflow needs are considered. Rather than a &#x2018;file-format-first&#x2019;
      approach, we should move towards a &#x2018;workflow-first&#x2019; approach.</p>
    <p class="paragraph">So we need to first consider, at a somewhat simplified level, the operations each of the main
      categories of stakeholders in a single source publishing system have to perform:</p>
    <p class="paragraph"><strong>Content</strong>&#xA0;&#x2013; ability to change the content</p>
    <p class="paragraph"><strong>Design</strong>&#xA0;&#x2013; ability to change the look and feel of outputs</p>
    <p class="paragraph"><strong>Format</strong>&#xA0;&#x2013; ability to change the structure of outputs.</p>
    <p class="paragraph">Setting aside the search for tools for a minute, it might be reasonable to ask &#x2013; is this
      approach even possible? Don&#x2019;t each of these operations require something quite different from a file
      format? So don&#x2019;t we require different formats to service each phase? It seems, in the history of publishing
      so far, systems designers have appeared to believe this to be true. This is why many publishing systems upconvert
      to the &#x2018;highest resolution&#x2019; format possible (generally some form of xml) as early as possible, and
      then downconvert to specific formats for consumption by tools such as InDesign.</p>
    <p class="paragraph"></p>
    <figure><img
        src="/images/uploads/A5-Img1.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">But it is possible for a single format to contain enough information to feed into each of these
      operations. Let&#x2019;s look again at each category of operations:</p>
    <h3>Content</h3>
    <p class="paragraph">First, the content folks must be able to edit a relatively easy-to-understand document.
      Authors, etc, in most cases prefer a document which contains only what is known as &#x2018;display
      semantics&#x2019; as they don&#x2019;t generally work with tools that enforce structure, rather they write from
      top to bottom with a structure that is meaningful to them via the headings, indents etc displayed in the actual
      document.</p>
    <p class="paragraph">Authors of this kind, which is most authors, &#x2018;just like to write&#x2019;. They
      don&#x2019;t care too much for having to maintain anything beyond the text, other than how the document looks to
      the eye.</p>
    <p class="paragraph">So any format we choose must be able to support a suite of tools that these kinds of authors
      can use. Generally speaking these tools are known as &#x2018;word processors&#x2019;.</p>
    <h3>Design</h3>
    <p class="paragraph">Designers must be able to take the same content and apply design to the content within the
      constraints of the output format. For example, designers must make the document look good in paginated PDF for
      printing (eg books), or EPUB, or the web etc.</p>
    <p class="paragraph">Any suite of tools we choose must enable designers to change placement, color etc of all the
      elements in the content as well as controlling the same for format-specific features (eg running headers, page
      numbers etc) for each output type while using the same source file. Generally, to date, the typical tools for
      designers have been what is sometimes referred to as &#x2018;pixel pushing&#x2019; tools &#x2013; tools where you
      can point and click to target elements and change their look and feel. However, in recent years (well, for a while
      now) there have been &#x2018;rules based&#x2019; design tools. One such rule-based approach is CSS &#x2013; the
      set of rules web designers use to determine the display format of webpages.</p>
    <h3>Format</h3>
    <p class="paragraph">Format wranglers want to be able to output file formats required for archiving, transmission,
      and storage. JATS (Journal Article Tagging Suite) is one such format, it is a variant of XML. Books have BITS
      (Book Interchange Tag Suite) which is also a XML variant.</p>
    <p class="paragraph">Format wranglers need the source file to contain enough information so the content can be
      translated (restructured) to the new form. Format wranglers are a kind of technician&#x2014;someone that is expert
      in encapsulating data in logical structures. The tools for these folks have generally been specialist
      pseudo-scripting tools such as XSL (Extensible Stylesheet Language) which is part of the family of XML tools.
      However, there are other approaches &#x2013; JSON, for example, is often used as a way to represent data,
      especially for transferring or storing data for web applications. With JSON, transformation is managed by rules
      encased in custom JavaScript code. But in essence, good format wranglers like to write rules that can transform
      many files, they don&#x2019;t like manually transforming each file.</p>
    <p class="paragraph">For a format to meet the needs of each of these use cases, there are two factors that must come
      into play:</p>
    <ol>
      <li>
        <p class="paragraph">any alterations to the content by content, design, or format people, MUST affect only one
          source &#x2013; the single source</p>
      </li>
      <li>
        <p class="paragraph">the source file format must contain enough information to service each of the tools used by
          these folks</p>
      </li>
    </ol>
    <p class="paragraph">That seems to make sense&#x2026; but there is one additional issue that is very important and
      which may not be so obvious. Any of the tools used can of course augment the source file with information for the
      job at hand while not requiring that information to actually be part of the source file.</p>
    <p class="paragraph">A good example is with transformation. The transformation folks can write a set of rules that
      can map the source file onto another structure (such as JATS). To do this they need two things:</p>
    <ol>
      <li>
        <p class="paragraph">enough information in the source file to enable the transformation. For example, to map
          A-&gt;B the source file must first tell us what A is .</p>
      </li>
      <li>
        <p class="paragraph">a set of rules that manage the execution of the transformation</p>
      </li>
    </ol>
    <p class="paragraph">The interesting thing is that the rules ([2] above) for the transformation do not have to be
      contained within our source file. These rules can exist entirely independently of the source file.</p>
    <p class="paragraph">In this way the format wranglers can do a lot of things no one else cares about, without
      overloading the source file with all kinds of requirements. This helps us keep the amount of information the
      actual source file needs to contain to a minimum.</p>
    <p class="paragraph">This is, if you had not realized this already, exactly the opposite to the way publishing
      systems designers have approached this process to date.</p>
    <p class="paragraph">So, let&#x2019;s say this makes sense so far. But what of content creation and design?</p>
    <p class="paragraph">For editing/content creation we need a format that doesn&#x2019;t break if it is &#x2018;badly
      structured&#x2019;. You may not know it, but if there is one thing authors are very good at, it is badly
      structuring documents. So, we need a format that doesn&#x2019;t care if the author structures things oddly. We can
      clean that aspect up later.</p>
    <p class="paragraph">This brings about an interesting quality of the file format. It must be capable of
      being&#xA0;<em>progressively structured</em>. That is, we can start with a &#x2018;badly structured&#x2019;
      document and the source file format won&#x2019;t break. We can then improve the structure over time and the file
      format will also be happy to do this.</p>
    <p class="paragraph">This is also, not the way it has been managed to date in publishing systems.</p>
    <p class="paragraph">Now to design. Design requirements are very similar to the requirements for format wrangling.
      We need the source file format to hold just enough information so that we can design elements with our design
      tools, but any further logic can be contained within separate rules and not contained within the source file. Once
      again, that allows us to keep the requirements of the source file to a minimum.</p>
    <h3>Ecosystem Features</h3>
    <p class="paragraph">So, we have two sets of qualities when choosing our ecosystem &#x2014; one set of features for
      the source file format, and one for the types of tools we choose. For the file format we need this:</p>
    <ol>
      <li>
        <p class="paragraph">contains just enough information for each of the operations (create, transform, design)</p>
      </li>
      <li>
        <p class="paragraph">can be progressively structured.</p>
      </li>
    </ol>
    <p class="paragraph">For the tools we need this feature:</p>
    <ol>
      <li>
        <p class="paragraph">the design and transformation are managed by logic external to the source file format.</p>
      </li>
    </ol>
    <figure><img
        src="/images/uploads/A5-Img2.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">Where does that leave us? As it happens, it leaves us with the ecology of tools that surround
      one of the most popular formats of our age &#x2013; HTML.</p>
    <h2>Concurrency</h2>
     <p class="paragraph">In publishing there are two types of concurrency we care about:</p>
    <ol>
      <li>
        <p class="paragraph"><strong>workflow concurrency</strong>&#xA0;&#x2013; the ability to perform multiple tasks
          upon the work, by different people, at the same time</p>
      </li>
      <li>
        <p class="paragraph"><strong>realtime editing</strong>&#xA0;&#x2013; the ability for multiple people to edit a
          document at the same time and see each other&#x2019;s changes in realtime (like Google Docs, or&#xA0;<a
            href="https://www.plasmic.app/" rel target="blank">Plasmic</a>&#xA0;/&#xA0;<a href="https://www.figma.com/"
            rel target="blank">Figma</a>&#xA0;etc)</p>
      </li>
    </ol>
    <p class="paragraph">These two overlap but they are distinct. Here is a brief example to illustrate the difference.
      In a book production workflow, we may break the work (book) up into multiple documents &#x2013; one for each
      chapter or even per paragraph (sometimes referred to as batching). Just by doing this we can have more than one
      person working on the book at the same time (each tackling a different chapter for example).</p>
    <figure><img
        src="/images/uploads/A6-Img1.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">This is workflow concurrency.</p>
    <p class="paragraph">Now, if we want two people to edit the same chapter at the same time this is realtime editing.
    </p>
    <figure><img
      src="/images/uploads/A6-Img2.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">Of course we can blend these two models:</p>
    <p class="paragraph"></p>
    <figure><img
      src="/images/uploads/A6-Img3.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">Now, realtime editing, as a type of concurrency, is a choice you have depending on the type of
      technology you choose for editing (there are also concurrent design apps like&#xA0;<a
        href="https://www.plasmic.app/" rel target="blank">Plasmic</a>&#xA0;and&#xA0;<a href="https://www.figma.com/"
        rel target="blank">Figma</a>). If you choose to use Microsoft Word for content creation, for example, you cannot
      achieve realtime editing. If you choose other tools (eg Google Docs, or&#xA0;<a
        href="https://github.com/xylk/prosemirror-firebase" rel target="blank">ProseMirror and
        Firebase</a>&#xA0;/&#xA0;<a href="https://demos.yjs.dev/prosemirror/prosemirror.html" rel
        target="blank">ProseMirror and yjs</a>) then you&#xA0;<em>can</em>&#xA0;achieve simultaneous realtime editing.
    </p>
    <p class="paragraph">But it is good to remember that if the technology does offer realtime editing then there is
      nothing forcing you to use it. Whether you use it or not is dependent on how you want people to work. Previously
      in this series of articles about single source publishing workflows, I suggested we do not design publishing
      platforms starting from technical features (such as choosing the source file format first), but rather we take a
      workflow-first approach. It is the same with realtime editing &#x2013; first work out your ideal workflow, and if
      indeed you actually want realtime editing, then add that to your list of system requirements. The technical
      consequences are a secondary problem.</p>
    <p class="paragraph">As for workflow concurrency &#x2013; we have the same set of questions. Do we want multiple
      people to perform different types of tasks on the work at the same time? Do we want, for example, the designer to
      be working on the layout as the copy editor does their work? Or an illustrator to be designing illustrations while
      an author is commenting on the illustration at the same time? These workflow concurrency questions must be
      answered when choosing or designing a publishing system, and once again it comes down to your answer to the
      crucial question &#x2013; &#x201C;what is my ideal workflow&#x201D;. Other decisions follow from there.</p>
    <p class="paragraph">Given all this, it is a good idea to first zoom out and question what value concurrency, of any
      kind, can offer a publishing workflow. We can then answer whether we actually want concurrency.</p>
    <h3>Concurrency vs Sequential Workflows</h3>
    <p class="paragraph">Publishing workflows these days are mostly sequential. A sequential workflow requires
      operations to be executed one after the other. Many publishers today, for example, are emailing (or uploading and
      downloading) bunches of documents for each other, usually in the MS Word format, to work on. An author emails
      files to a acquisition manager, who emails them to the production crew, who back and forth with authors and copy
      editors etc to get all the files processed (or &#x201C;done_done_final_done_really-final-done_v2&#x201D; as the
      case may be) and then the same files are sent to a designer/vendor etc</p>
    <p class="paragraph">This is very sequential and we know its downside because that is how things work today. We know
      how much time and money these workflows cost (much more than necessary).</p>
    <p class="paragraph">The question is whether concurrency is better? To answer this question we have to understand
      the essential characteristics of concurrency, and how they can help publishers.</p>
    <p class="paragraph">There are two essential characteristics of concurrency:</p>
    <ol>
      <li>
        <p class="paragraph">the opportunity to see the current state of the work at any moment</p>
      </li>
      <li>
        <p class="paragraph">the opportunity to act on the current work at any moment.</p>
      </li>
    </ol>
    <p class="paragraph">There is a lot to gain from these two simple features. From a very high level there are 4
      general gains on offer that are derived from [1] and [2] above:</p>
    <p class="paragraph">1.<strong>&#xA0;understanding state</strong>&#xA0;&#x2013; an immediate understanding of the
      state of the work at any moment</p>
    <p class="paragraph"></p>
    <figure><img
      src="/images/uploads/A6-Img4.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">2.<strong>&#xA0;reducing handling time</strong>&#xA0;&#x2013; reducing the to and fro of
      passing documents back and forth</p>
    <p class="paragraph"></p>
    <figure><img
      src="/images/uploads/A6-Img5.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">3.&#xA0;<strong>parallel processes</strong>&#xA0;&#x2013; various team members can do what they
      need to do in parallel with each other</p>
    <p class="paragraph"></p>
    <figure><img
      src="/images/uploads/A6-Img6.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">4.&#xA0;<strong>realtime problem solving</strong>&#xA0;&#x2013; issues can be resolved in
      realtime.</p>
    <p class="paragraph"></p>
    <figure><img
      src="/images/uploads/A6-Img7.jpg">
      <figcaption class="decoration"></figcaption>
    </figure>
    <p class="paragraph">These 4 opportunities provided by concurrency can have, even if moderately implemented, a huge
      impact as Ken Brooks has attested:</p>
    <blockquote>
      <p class="paragraph">&#x201C;By implementing collaborative editing, WYSIWYG rendering, and push-button
        distribution to all formats (courses, eBooks and print files) we discovered it can result in a 50% reduction in
        cost and a 50% reduction in cycle.&#x201D;<br>&#x2014;<a href="https://www.linkedin.com/in/kmbrooks" rel
          target="blank">Ken Brooks</a>, president, Treadwell Media Group.</p>
    </blockquote>
    <p class="paragraph">But concurrency also allows for completely new ways of working, as Barbara R&#xFC;hling from
      Book Sprints points out:</p>
    <blockquote>
      <p class="paragraph">&#x201C;Book Sprints would not be able to produce books in 5 days if authors, illustrators,
        copy editors, designers etc were not all able to work concurrently. &#x201D;<br>&#x2014; Barbara R&#xFC;hling,
        CEO,&#xA0;<a href="https://booksprints.net/" rel target="blank">Book Sprints</a></p>
    </blockquote>
    <p class="paragraph">How much concurrency benefits your workflow depends on which parts of the cycle you decide to
      make concurrent, and just how far you are prepared to go. How far you take it is up to you.</p>
    <p class="paragraph">Here are some examples of where concurrency could benefit a common publishing workflow:</p>
    <ul>
      <li>
        <p class="paragraph">Art logs and image research starting as soon as FPO (&#x2018;for placement only&#x2019;)
          images are placed</p>
      </li>
      <li>
        <p class="paragraph">Alt text being created as images are being added</p>
      </li>
      <li>
        <p class="paragraph">Indexing could start as the text is completed (inserting tags) before the proof stage</p>
      </li>
      <li>
        <p class="paragraph">Proofing being finished on one part of the book before the rest is finished</p>
      </li>
      <li>
        <p class="paragraph">Concurrent page rendering enables author to correct or fit content as they write it</p>
      </li>
      <li>
        <p class="paragraph">Testing the content with live customers as the rest of the content is being finished
          (O&#x2019;Reilly does this, and it&#x2019;s a way to do A/B testing for learning objects and assessment items
          in education. It&#x2019;s a way to improve product-market fit).</p>
      </li>
      <li>
        <p class="paragraph">Multiple authors working on the same text at the same time</p>
      </li>
      <li>
        <p class="paragraph">Designers working on design of the actual content as a work is being created</p>
      </li>
      <li>
        <p class="paragraph">Copy editors working on content immediately as it is completed by an author</p>
      </li>
      <li>
        <p class="paragraph">Illustrators placing images in a work as it is being authored</p>
      </li>
      <li>
        <p class="paragraph">Production editors understanding exactly what has and hasn&#x2019;t been done at any time
        </p>
      </li>
      <li>
        <p class="paragraph">Developmental editors and authors working on the same text at the same time</p>
      </li>
    </ul>
    <h3>SSP and Concurrency</h3>
    <h3>So, what about SSP and concurrency?</h3>
    <p class="paragraph">Remember these two features of concurrency listed above:</p>
    <ol>
      <li>
        <p class="paragraph">the opportunity to see the current state of the work at any moment</p>
      </li>
      <li>
        <p class="paragraph">the opportunity to act on the current work at any moment.</p>
      </li>
    </ol>
    <p class="paragraph">These two features require the source to be shared between all those in the team. To have
      concurrency, on a system or document level, we need to share the source &#x2026; sound familiar? Sharing the
      source is the same core design requirement of a single source publishing system. SSP offers more opportunity by
      design for concurrency than does a &#x2018;multiple master&#x2019; publishing system.</p>
    <p class="paragraph">SSP can offer publishing enormous gains through the introduction of concurrency into the
      workflow. Concurrency can help optimise how you work, or it can radically change how you work. How much you take
      advantage of SSP and concurrency is completely up to you. The advantage of SSP is that you have a choice, as
      Andrew Savikas points out:</p>
    <blockquote>
      <p class="paragraph">&#x201C;Concurrency is so powerful. It means it&#x2019;s possible to (for example) have an
        author, copy editor, indexer, and designer all making changes in different parts of the manuscript at the same
        time. Of course, it does not always (or even often) make sense for each step of the workflow to be done
        concurrently, but an SSP model at least makes it possible. &#x201C;<br>&#x2014; Andrew Savikas, &#xA0;Chief
        Strategy Officer at&#xA0;<a href="https://www.getabstract.com/" rel target="blank">getAbstract</a></p>
    </blockquote>
    <p class="paragraph">(c) Adam Hyde, 2021. This work is licensed under a&#xA0;<a
        href="http://creativecommons.org/licenses/by/4.0/" rel target="blank">Creative Commons Attribution 4.0
        International License</a>.</p>
    <p class="paragraph"><em>Thanks to Wendell Piez, Ken Brooks, Andrew Savikas and John Maxwell for feedback. Thanks
        also to Henrik van Leeuwen for the images and Raewyn Whyte for copy editing.</em></p>
